# Standard rules for building modules
# CURDIR must be defined
proto:
	proto -m0+ -b$(CURDIR).h+$(CURDIR).pm $(PROTOUPDHEAD) *.cc

SOPATH=$(CURDIR).so.$(LINUXCONF_REV).$(LINUXCONF_SUBREV)

ifdef OLDGCC
$(CURDIR).so: $(OBJS)
	@echo Linuxconf can\'t handle a.out module, sorry
else
$(CURDIR).so: $(OBJS)
	$(GPPLINK) -g -shared -Wl,-soname,$(CURDIR).so.1 -o \
		$(SOPATH) \
		$(OBJS) $(EXTRAMODLIBS)
endif

std_local_clean:
	rm -f $(CURDIR).so.* `find . -name \*.bak`

# Check if we are in linuxconf source tree
# If not, we are using resources in linuxconf-devel package
ifeq "$(shell test -x $(LINUXCONF_PATH)/translate/msgcomp && echo ok)" "ok"
MSGCOMP=$(LINUXCONF_PATH)/translate/msgcomp
COPYDIR=../copydir.sh
RPMSPEC=../../builder/module.rpmspec
FILTERSPEC=../../builder/filterspec.sh
else
MSGCOMP=/usr/lib/linuxconf-devel/msgcomp
COPYDIR=/usr/lib/linuxconf-devel/copydir.sh
RPMSPEC=/usr/lib/linuxconf-devel/module.rpmspec
FILTERSPEC=/usr/lib/linuxconf-devel/filterspec.sh
endif


std_local_install:
	mkdir -p $(LIB_LINUXCONF)/modules
	mkdir -p $(LIB_LINUXCONF)/images
	mkdir -p $(LIB_LINUXCONF)/help.eng
	install -o root -g root -m 755 $(SOPATH) $(LIB_LINUXCONF)/modules
	$(MSGCOMP) -p./ -p$(LINUXCONF_HELP)/ \
		$(LIB_LINUXCONF)/help.eng/$(CURDIR)-msg-$(PACKAGE_REV).eng eE \
		$(CURDIR)
	@if [ -f $(CURDIR).xpm ]; then \
		echo installing $(LIB_LINUXCONF)/images/$(CURDIR).xpm; \
		install -o root -g root -m 644 $(CURDIR).xpm $(LIB_LINUXCONF)/images; \
		fi
	@if [ -f $(CURDIR).gif ]; then \
		echo installing $(LIB_LINUXCONF)/images/$(CURDIR).gif; \
		install -o root -g root -m 644 $(CURDIR).gif $(LIB_LINUXCONF)/images; \
		fi


install_daemons:
	mkdir -p $(LIB_LINUXCONF)/redhat
	test ! -d redhat || cp -a redhat/. $(LIB_LINUXCONF)/redhat/.

# Rules to build RPM, for module developped outside of the linuxconf source tree

SOURCEDIR=$(CURDIR)-$(PACKAGE_REV)

buildrpm: buildspec buildsrc
	rpm -ba /usr/src/redhat/SPECS/$(CURDIR)-$(PACKAGE_REV).spec

buildspec:
	sed s/MODULENAME/$(CURDIR)/ $(RPMSPEC) \
		| sed s/PACKAGEREV/$(PACKAGE_REV)/ \
		| sed s/SOURCE/$(SOURCEDIR).src.tar.gz/ \
		| $(FILTERSPEC) >/usr/src/redhat/SPECS/$(SOURCEDIR).spec	

buildsrc:
	rm -fr /tmp/$(SOURCEDIR)
	mkdir /tmp/$(SOURCEDIR)
	cp -a . /tmp/$(SOURCEDIR)/.
	(cd /tmp/$(SOURCEDIR) && make clean)
	(cd /tmp && tar zcvf /usr/src/redhat/SOURCES/$(SOURCEDIR).src.tar.gz $(SOURCEDIR) )

